function example_isap_BIO427
%
% Simulates and performs path-wise sensitivity analysis for the BIO520 reaction
% network taken from www.ebi.ac.uk/.
%
% (c) Math & Stat, Umass, Amherst, 2014

% files and directories
dname = 'examples/BIO427/'; % directory with the reaction network
fname = [dname 'input_files/BIO427']; % file with the reactions

% create auxiliary files, if necessary
exCM = dir([fname '_connectivity.txt']);
if isempty(exCM) % if connectivity matrix does not exist, create it
    rxn2csm([fname '.txt']);
end

% initialize data
% data = initialization_lin(fname);  % for linear-scale sensitivity analysis
data = initialization_log(fname); % for log-scale sensitivity analysis

data.T = 100; % final time
data.NoJ = 10^6; % maximum number of jumps

data.NoS = 5; % number of repeated simulations
dt = .1; % sampling frequency in time
data.ti = dt : dt : data.T; % sampling time instants

% simulate the reaction network and save the species time-series
% sim_rxn(data, [dname 'data/'], 'SSA');
sim_rxn(data, [dname 'data/'], 'MFA');
% sim_rxn(data, [dname 'data/'], 'CLE');
% 
% % plot the species of the reaction network
% plot_species(data, [dname 'data/X_SSA_1.mat'], [3,1,1], 6);
% title('SSA');
% 
% plot_species(data, [dname 'data/X_MFA_1.mat'], [3,1,2], 6);
% title('MFA');
% 
% plot_species(data, [dname 'data/X_CLE_1.mat'], [3,1,3], 6);
% title('CLE');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%    PATHWISE SENSITIVITY ANALYSIS    %%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% create perturbation vectors
eps0 = .1; % 10% parameter perturbation
pert_vec = diag(eps0*data.con);
pert_vec = [pert_vec; -pert_vec]; % +10% and -10% perturbation

data.eps0 = eps0;
data.pert_vec = pert_vec;

% compute PFIM and/or RER
PFIM = compute_PFIM_RER(data, dname);
%[PFIM, RER] = compute_PFIM_RER(data, dname);

tempF=PFIM;
idx = tempF~=0;
tempF(idx) = log(abs(tempF(idx)));

% plot 3D PFIM
figure;
plot_PFIM(tempF, data);


% plot
figure;
spy(PFIM(:,:,1));
title('Block diagonal structure of Path-wise FIM', 'FontSize', 12);

% plot various RERs (perturbation vector must have specific structure)
%figure;
%plot_RER(RER, PFIM, data);