function test_methods_EGFR
%
% Simulates the EGFR reaction network.
%
% (c) Math & Stat, Umass, Amherst, 2014

% files and directories
dname = 'examples/EGFR/'; % directory with the reaction network
fname = [dname 'input_files/EGFR']; % file with the reactions

% create auxiliary files, if necessary
exCM = dir([fname '_connectivity.txt']);
if isempty(exCM) % if connectivity matrix does not exist, create it
    rxn2csm([fname '.txt']);
end

% initialize data
% data = initialization_lin(fname);  % for linear-scale sensitivity analysis
data = initialization_log(fname); % for log-scale sensitivity analysis

data.T = 100; % final time
data.NoJ = 10^6; % maximum number of jumps

data.NoS = 1; % number of repeated simulations
dt = .1; % sampling frequency in time
data.ti = dt : dt : data.T; % sampling time instants
data.tau = .1; % time-step for CLE

% simulate the reaction network and save the species time-series
sim_rxn(data, [dname 'data/'], 'SSA');
sim_rxn(data, [dname 'data/'], 'MFA');
sim_rxn(data, [dname 'data/'], 'CLE');

% plot the species of the reaction network
plot_species(data, [dname 'data/X_SSA_1.mat'], [3,1,1], 6);
title('SSA');

plot_species(data, [dname 'data/X_MFA_1.mat'], [3,1,2], 6);
title('MFA');

plot_species(data, [dname 'data/X_CLE_1.mat'], [3,1,3], 6);
title('CLE');

