function F = update_PFIM(data, F, dt)
%
% 	Update PFIM
%
%  ---- INPUT PARAMETERS ----
%   data: data struct array
%
%   data.K: number of parameters, [1x1] 
%   data.X: current population of the system, [Nx1]
%   data.cv_glpf: vector of the non-zero elements of the symbolic PFIM, [prop_lenx1]
%   data.prop_index: index of the non-zero elements of the symbolic PFIM, [prop_lenx1]
%   data.con: value of reaction constants, [Kx1]
%
%   F: Fisher Information Matrix, [KxK]
%   dt: time difference between two jumps, [1x1]
%
% ---- OUTPUT PARAMETERS ----
%   F: Updated pathwise Fisher Information Matrix, [KxK]
%  
% (c) Math & Stat, Umass, Amherst, 2014

% Evaluate propensity functions at each jump and store the value in vector
len=length(data.cv_glpf);
value_glpf=zeros(len,1);
for i=1:len
    value_glpf(i)=get_PFIM(i, data);
    if isnan(value_glpf(i))
        value_glpf(i)=0;
    end
end

% Row number in sparse matrix
xpos=ceil(data.prop_index/data.K); 
% Column number in sparse matrix
ypos=rem(data.prop_index,data.K);
ypos(ypos==0)=data.K;
% Create sparse matrix
spm=sparse(xpos,ypos,value_glpf,data.K,data.K);
% Update PFIM
F = F+dt*spm;


