function update = update_RER_per(data, dt, veps)
%
%   Update RER
%
%  ---- INPUT PARAMETERS ----
%   data: data structure array
%
%   data.M: number of reactions, [1x1]
%   data.X: current population of the system, [Nx1]
%   data.con: value of reaction constants, [Kx1]
%   data.stoichio: stoichiometric matrix, [Mx4]
%   data.cm_spe: connectivity matrix for the species, [MxK+1]
%
%   dt: time difference between two jumps, [1x1]
%   veps: vector of perturbations, [Kx1]
% ---- OUTPUT PARAMETERS ----
%   update: change of RER in current iteration, [1x1]
%
% (c) Math & Stat, Umass, Amherst, 2014

% Rates initialization
c = zeros(data.M, 1);
for k = 1:data.M
    c(k) = reaction_rate(data, k);
end
c0 = sum(c);

% Perturbed rates initialization
c_eps = zeros(data.M, 1);
con=data.con; % save the original rate constants
for k = 1:data.M
    c_eps(k) = rate_eps(data, veps, k); % overwrite rate constants with perturbations
end
c0_eps = sum(c_eps);
data.con=con; % restore the original rate constants

rer=0;
for i = 1:data.M
    if (c_eps(i)~=0 && c(i)~=0)
        rer=rer+c(i)*log(c(i)/c_eps(i));
    end
end
rer=rer-(c0-c0_eps);
update=dt*rer;